const fs=require('fs');

/**
 * Synchronous
 
 * Replaces variables in the HTML file with some values
 
 * @filename Path of the HTML file
 * @data A JSON object with keys as the variables
 * 
 * and values as the text to be replaced
 * 
 * Example: 
 * #html code>> <h1>{(:text:)}</h1>
 * #nodejs code>> var res=renderSync("index.html",{"text":"Hello world"});
 * 
 * console.log(res);
 * #result html code>> <h1>Hello World</h1>
*/
function renderSync(filename=String,data=JSON){
  if (filename==null){
    throw Error("Filename not defined");
  }

  if (data==null){
    throw Error("Render data not defined");
  }

  else{
    var key=Object.keys(data);
    var file=fs.readFileSync(filename,'utf-8');
    var index=0;
    var value;
    while (index<key.length){
      value=data[key[index]];
      htmlkey="{(:"+key[index]+":)}";
      if (file.includes(htmlkey)){
        var occurence=file.split(htmlkey).length;
        var index2=0;
        while (index2<occurence){
          file=file.replace(htmlkey,value);
          index2++;
        }
      }
      index++;
    }
    return file;
  }
}

/**
 * Asynchronous
 
 * Replaces variables in the HTML file with some values
 
 * @filename Path of the HTML file
 * @data A JSON object with keys as the variables
 * and values as the replaced text
 * 
 * Example: 
 * #html code>> <h1>{(:text:)}</h1>
 * #nodejs code>> renderSync("index.html",{"text":"Hello world"})
 * 
 * .then(res=>{
 * 
 *    console.log(res);
 * 
 *  });
 * #result html code>> <h1>Hello World</h1>
*/
async function render(filename=String,data=JSON){
  if (filename==null){
    throw Error("Filename not defined");
  }

  if (data==null){
    throw Error("Render data not defined");
  }

  else{
    var key=Object.keys(data);
    var res;
    fs.readFile(filename,'utf8',(err,file)=>{
      var index=0;
      var value;
      while (index<key.length){
        value=data[key[index]];
        htmlkey="{(:"+key[index]+":)}";
        if (file.includes(htmlkey)){
          var occurence=file.split(htmlkey).length;
          var index2=0;
          while (index2<occurence){
            file=file.replace(htmlkey,value);
            index2++;
          }
        }
        index++;
      }
      res=file;
    })

    return new Promise(resolve=>{setTimeout(()=>{resolve(res)},50)})
  }
}

module.exports={render,renderSync}